=====
Usage
=====

To get access to the data,

.. code-block:: python

    from databroker import catalog

    db = catalog["example"]
    run = db[0]

Then, follow the instruction of `databroker <https://nsls-ii.github.io/databroker/v2/user/index.html>`_.
